==> friday_ai_cli-0.1.0.tar.gz: friday_ai_cli-0.1.0/PYPI.md <==
<div align="center">

![image](https://tomato-suzy-27.tiiny.site/1.png)
# FRIDAY AI CLI

**Forget Refactoring, I Do All Your Coding Now!**

[![Python Version](https://img.shields.io/badge/python-3.11%2B-blue.svg)](https://www.python.org/downloads/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![PyPI Status](https://img.shields.io/pypi/status/friday-ai-cli.svg)](https://pypi.org/project/friday-ai-cli/)
[![PyPI version](https://badge.fury.io/py/friday-ai-cli.svg)](https://badge.fury.io/py/friday-ai-cli)
[![PyPI Downloads](https://static.pepy.tech/badge/friday-ai-cli/week)](https://pepy.tech/projects/friday-ai-cli)


*A powerful AI-powered CLI tool for developers, built on Anthropic's Claude 3*

</div>

---

## 🚀 Overview

FRIDAY AI CLI is your intelligent development companion powered by Anthropic's Claude 3 Sonnet. It helps developers with various software development tasks, from code writing to project structuring, all through an intuitive command-line interface designed for maximum productivity.

## ✨ Features

- 💻 **Intelligent Development Assistance**
  - Code writing and review
  - Project structure optimization
  - Best practices implementation
  - Problem-solving support

- 🛠️ **Development Workflow Support**
  - Environment setup assistance
  - Dependency management help
  - Project scaffolding guidance
  - Documentation generation

- 🔐 **Secure and Convenient**
  - API key saved securely for future sessions
  - License-based access to premium features
  - Memory-only decryption of protected code
  - Persistent chat history (coming soon)

- 👾 **Interactive Interface**
  - Real-time responses
  - Syntax-highlighted code
  - Color-coded outputs
  - Clear visual hierarchy

## 📦 Installation

```bash
pip install friday-ai-cli
```

### Requirements
- Python 3.11 or higher
- Anthropic API key ([Get one here](https://console.anthropic.com/))
- License key for premium features (contact me for details)

## 🎯 Quick Start

1. Set your Anthropic API key (only needs to be done once):
```bash
friday set-api-key 'your-anthropic-api-key'
```

2. Activate your license (premium features):
```bash
friday add-license 'your-license-key'
```

3. Start FRIDAY:
```bash
friday chat
```

4. Check configuration and status:
```bash
friday version
```

## 🖥️ Available Commands

```bash
# Start a chat session
friday chat

# Set your Anthropic API key (saved for future use)
friday set-api-key YOUR_API_KEY

# Remove your saved API key
friday reset-api-key

# Add/update your license key (for premium features)
friday add-license YOUR_LICENSE_KEY

# Remove your license key
friday reset-license

# Display version and configuration information
friday version
```

## 💡 Usage Examples

```bash
# Get development help
You › How do I structure a Flask API project?

# Code review
You › Can you review this code snippet? [paste code]

# Project setup
You › Help me set up a new React project with TypeScript and Tailwind
```

## 🎨 Interface

FRIDAY uses a color-coded interface for clear communication:

- 👤 User Messages (Cyan)
- 🤖 FRIDAY Responses (Green)
- 🔧 Tool Usage (Yellow)
- 📤 Tool Output (Blue)

## 🔒 Security

- Secure API key storage with proper permissions
- API key masking (only showing first/last 4 characters)
- Protected core modules with memory-only decryption
- Permission-based operations for system commands
- Local-only file operations

## 🌐 Learn More

To learn more about the me and see FRIDAY in action:
- Visit my portfolio: [https://portfolio.yashchouriya.com/](https://portfolio.yashchouriya.com/)
- Contact me for license keys
- A dedicated license management website is coming in future updates

## 🤝 Support

For support or feature requests, please contact:
- Email: [yashchouriya131@gmail.com](mailto:yashchouriya131@gmail.com)

## 📄 License

This project is available under a dual license model:
- Core functionality: MIT License
- Premium features: Commercial License (requires activation)

---

<div align="center">

Made with ❤️ by Yash Chouriya

</div>

==> friday_ai_cli-0.1.1.tar.gz: friday_ai_cli-0.1.1/PYPI.md <==
<div align="center">

![image](https://tomato-suzy-27.tiiny.site/1.png)
# FRIDAY AI CLI

**Forget Refactoring, I Do All Your Coding Now!**

[![Python Version](https://img.shields.io/badge/python-3.11%2B-blue.svg)](https://www.python.org/downloads/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
![PyPI - Version](https://img.shields.io/pypi/v/friday-ai-cli)
[![PyPI Downloads/Month](https://static.pepy.tech/badge/friday-ai-cli/month)](https://pepy.tech/projects/friday-ai-cli)
[![PyPI Downloads](https://static.pepy.tech/badge/friday-ai-cli)](https://pepy.tech/projects/friday-ai-cli)


*A powerful AI-powered CLI tool for developers, built on Anthropic's Claude 3*

</div>

---

## 🚀 Overview

FRIDAY AI CLI is your intelligent development companion powered by Anthropic's Claude 3 Sonnet. It helps developers with various software development tasks, from code writing to project structuring, all through an intuitive command-line interface designed for maximum productivity.

## ✨ Features

- 💻 **Intelligent Development Assistance**
  - Code writing and review
  - Project structure optimization
  - Best practices implementation
  - Problem-solving support

- 🛠️ **Development Workflow Support**
  - Environment setup assistance
  - Dependency management help
  - Project scaffolding guidance
  - Documentation generation

- 🔐 **Secure and Convenient**
  - API key saved securely for future sessions
  - License-based access to premium features
  - Memory-only decryption of protected code
  - Persistent chat history (coming soon)

- 👾 **Interactive Interface**
  - Real-time responses
  - Syntax-highlighted code
  - Color-coded outputs
  - Clear visual hierarchy

## 📦 Installation

```bash
pip install friday-ai-cli
```

### Requirements
- Python 3.11 or higher
- Anthropic API key ([Get one here](https://console.anthropic.com/))
- License key for premium features (contact me for details)

## 🎯 Quick Start

1. Set your Anthropic API key (only needs to be done once):
```bash
friday set-api-key 'your-anthropic-api-key'
```

2. Activate your license (premium features):
```bash
friday add-license 'your-license-key'
```

3. Start FRIDAY:
```bash
friday chat
```

4. Check configuration and status:
```bash
friday version
```

## 🖥️ Available Commands

```bash
# Start a chat session
friday chat

# Set your Anthropic API key (saved for future use)
friday set-api-key YOUR_API_KEY

# Remove your saved API key
friday reset-api-key

# Add/update your license key (for premium features)
friday add-license YOUR_LICENSE_KEY

# Remove your license key
friday reset-license

# Display version and configuration information
friday version
```

## 💡 Usage Examples

```bash
# Get development help
You › How do I structure a Flask API project?

# Code review
You › Can you review this code snippet? [paste code]

# Project setup
You › Help me set up a new React project with TypeScript and Tailwind
```

## 🎨 Interface

FRIDAY uses a color-coded interface for clear communication:

- 👤 User Messages (Cyan)
- 🤖 FRIDAY Responses (Green)
- 🔧 Tool Usage (Yellow)
- 📤 Tool Output (Blue)

## 🔒 Security

- Secure API key storage with proper permissions
- API key masking (only showing first/last 4 characters)
- Protected core modules with memory-only decryption
- Permission-based operations for system commands
- Local-only file operations

## 🌐 Learn More

To learn more about the me and see FRIDAY in action:
- Visit my portfolio: [https://portfolio.yashchouriya.com/](https://portfolio.yashchouriya.com/)
- Contact me for license keys
- A dedicated license management website is coming in future updates

## 🤝 Support

For support or feature requests, please contact:
- Email: [yashchouriya131@gmail.com](mailto:yashchouriya131@gmail.com)

## 📄 License

This project is available under a dual license model:
- Core functionality: MIT License
- Premium features: Commercial License (requires activation)

---

<div align="center">

Made with ❤️ by Yash Chouriya

</div>
